Real (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Real)

`type t = real`
`val of_int : int -> t`
`val _to_int_round_down : t -> int`
`val to_int : t -> int`
`val (+) : real -> real -> real`
`val (-) : real -> real -> real`
`val (~-) : real -> real`
`val (*) : real -> real -> real`
`val (/) : real -> real -> real`
`val (<) : real -> real -> bool`
`val (<=) : real -> real -> bool`
`val (>) : real -> real -> bool`
`val (>=) : real -> real -> bool`
`val abs : real -> real`
`val min : real -> real -> real`
`val max : real -> real -> real`
`val mk_of_float : float -> Q.t`
`val mk_of_q : Q.t -> Q.t`
`val mk_of_string : string -> Q.t`
`val to_float : Q.t -> float`
`val of_float : float -> real`
`val compare : t -> t -> int`
`val pp : Stdlib.Format.formatter -> Q.t -> unit`
`val to_string : Q.t -> string`
`val to_string_approx : Q.t -> string`
`val pow_ : Q.t -> int -> Q.t`
`val pow : t -> Int.t -> t`